#|$ACL2s-Preamble$;
;; Author - Harsh Raju Chamarthi (harshrc)
(ld ; Matt K.: added linebreak to avoid build-system warning from LD
 "package.lsp")
(begin-book t);$ACL2s-Preamble$|#


(in-package "ACL2S")
